@@ -1,12 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2010 by Aleix Pol Gonzalez <aleixpol@kde.org>           *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2010 Aleix Pol Gonzalez <aleixpol@kde.org>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "projectsourcepage.h"
 #include "ui_projectsourcepage.h"
@@ -196,8 +192,7 @@ void ProjectSourcePage::checkoutVcsProject()
     m_ui->get->setEnabled(false);
     m_ui->creationProgress->setValue(m_ui->creationProgress->minimum());
     connect(job, &VcsJob::result, this, &ProjectSourcePage::projectReceived);
-    // Can't use new signal-slot syntax, KJob::percent is private :/
-    connect(job, SIGNAL(percent(KJob*,ulong)), SLOT(progressChanged(KJob*,ulong)));
+    connect(job, &KJob::percentChanged, this, &ProjectSourcePage::progressChanged);
     connect(job, &VcsJob::infoMessage, this, &ProjectSourcePage::infoMessage);
     ICore::self()->runController()->registerJob(job);
 }
