@@ -1,25 +1,10 @@
 /*
- * GDB Debugger Support
- *
- * Copyright 2003 John Birch <jbb@kdevelop.org>
- * Copyright 2006 Vladimir Prus <ghost@cs.msu.su>
- * Copyright 2007 Hamish Rodda <rodda@kde.org>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 2003 John Birch <jbb@kdevelop.org>
+    SPDX-FileCopyrightText: 2006 Vladimir Prus <ghost@cs.msu.su>
+    SPDX-FileCopyrightText: 2007 Hamish Rodda <rodda@kde.org>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "gdboutputwidget.h"
 
@@ -93,7 +78,7 @@ GDBOutputWidget::GDBOutputWidget(CppDebuggerPlugin* plugin, QWidget *parent) :
 
     slotStateChanged(s_none, s_dbgNotStarted);
 
-    connect(m_userGDBCmdEditor, QOverload<>::of(&KHistoryComboBox::returnPressed),
+    connect(m_userGDBCmdEditor, QOverload<const QString&>::of(&KHistoryComboBox::returnPressed),
             this, &GDBOutputWidget::slotGDBCmd);
     connect(m_Interrupt, &QToolButton::clicked, this, &GDBOutputWidget::breakInto);
 
