@@ -1,22 +1,8 @@
-/* KDevelop QMake Support
- *
- * Copyright 2006 Andreas Pakulat <apaku@gmx.de>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301, USA.
- */
+/*
+    SPDX-FileCopyrightText: 2006 Andreas Pakulat <apaku@gmx.de>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "qmakedriver.h"
 
@@ -81,6 +67,8 @@ bool Driver::parse(ProjectAST** qmast)
             DebugVisitor d(&qmakeparser);
             d.visitProject(ast);
         }
+        if (*qmast)
+            delete *qmast;
         *qmast = new ProjectAST();
         BuildASTVisitor d(&qmakeparser, *qmast);
         d.visitProject(ast);
